@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.DevopsGuru 1.17.75\n"
-        "Version:         1.17.75\n"
-        "Builder version: 4.13.1\n"
+        "Type annotations for boto3.DevOpsGuru 1.17.81\n"
+        "Version:         1.17.81\n"
+        "Builder version: 4.14.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-devops-guru/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.75")
+    print("1.17.81")
 
 
 def main() -> None:
