@@ -7,9 +7,9 @@ Usage::
 
     ```python
     import boto3
-    from mypy_boto3_devops_guru import DevopsGuruClient
+    from mypy_boto3_devops_guru import DevOpsGuruClient
 
-    client: DevopsGuruClient = boto3.client("devops-guru")
+    client: DevOpsGuruClient = boto3.client("devops-guru")
     ```
 """
 import sys
@@ -69,7 +69,7 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("DevopsGuruClient",)
+__all__ = ("DevOpsGuruClient",)
 
 
 class BotocoreClientError(BaseException):
@@ -91,9 +91,9 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class DevopsGuruClient:
+class DevOpsGuruClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -104,19 +104,19 @@ class DevopsGuruClient:
         self, Config: "NotificationChannelConfigTypeDef"
     ) -> AddNotificationChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.add_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.add_notification_channel)
         [Show boto3-stubs documentation](./client.md#add_notification_channel)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.can_paginate)
         [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def describe_account_health(self) -> DescribeAccountHealthResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_account_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_health)
         [Show boto3-stubs documentation](./client.md#describe_account_health)
         """
 
@@ -124,25 +124,25 @@ class DevopsGuruClient:
         self, FromTime: datetime, ToTime: datetime = None
     ) -> DescribeAccountOverviewResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_account_overview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_overview)
         [Show boto3-stubs documentation](./client.md#describe_account_overview)
         """
 
     def describe_anomaly(self, Id: str) -> DescribeAnomalyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_anomaly)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_anomaly)
         [Show boto3-stubs documentation](./client.md#describe_anomaly)
         """
 
     def describe_feedback(self, InsightId: str = None) -> DescribeFeedbackResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_feedback)
         [Show boto3-stubs documentation](./client.md#describe_feedback)
         """
 
     def describe_insight(self, Id: str) -> DescribeInsightResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_insight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_insight)
         [Show boto3-stubs documentation](./client.md#describe_insight)
         """
 
@@ -150,13 +150,13 @@ class DevopsGuruClient:
         self, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = None
     ) -> DescribeResourceCollectionHealthResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_resource_collection_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_resource_collection_health)
         [Show boto3-stubs documentation](./client.md#describe_resource_collection_health)
         """
 
     def describe_service_integration(self) -> DescribeServiceIntegrationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.describe_service_integration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.describe_service_integration)
         [Show boto3-stubs documentation](./client.md#describe_service_integration)
         """
 
@@ -168,13 +168,13 @@ class DevopsGuruClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.generate_presigned_url)
         [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_cost_estimation(self, NextToken: str = None) -> GetCostEstimationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.get_cost_estimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.get_cost_estimation)
         [Show boto3-stubs documentation](./client.md#get_cost_estimation)
         """
 
@@ -182,7 +182,7 @@ class DevopsGuruClient:
         self, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = None
     ) -> GetResourceCollectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.get_resource_collection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.get_resource_collection)
         [Show boto3-stubs documentation](./client.md#get_resource_collection)
         """
 
@@ -194,7 +194,7 @@ class DevopsGuruClient:
         NextToken: str = None,
     ) -> ListAnomaliesForInsightResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.list_anomalies_for_insight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.list_anomalies_for_insight)
         [Show boto3-stubs documentation](./client.md#list_anomalies_for_insight)
         """
 
@@ -202,7 +202,7 @@ class DevopsGuruClient:
         self, Filters: ListEventsFiltersTypeDef, MaxResults: int = None, NextToken: str = None
     ) -> ListEventsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.list_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.list_events)
         [Show boto3-stubs documentation](./client.md#list_events)
         """
 
@@ -213,7 +213,7 @@ class DevopsGuruClient:
         NextToken: str = None,
     ) -> ListInsightsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.list_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.list_insights)
         [Show boto3-stubs documentation](./client.md#list_insights)
         """
 
@@ -221,7 +221,7 @@ class DevopsGuruClient:
         self, NextToken: str = None
     ) -> ListNotificationChannelsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.list_notification_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.list_notification_channels)
         [Show boto3-stubs documentation](./client.md#list_notification_channels)
         """
 
@@ -229,19 +229,19 @@ class DevopsGuruClient:
         self, InsightId: str, NextToken: str = None, Locale: LocaleType = None
     ) -> ListRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.list_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.list_recommendations)
         [Show boto3-stubs documentation](./client.md#list_recommendations)
         """
 
     def put_feedback(self, InsightFeedback: "InsightFeedbackTypeDef" = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.put_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.put_feedback)
         [Show boto3-stubs documentation](./client.md#put_feedback)
         """
 
     def remove_notification_channel(self, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.remove_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.remove_notification_channel)
         [Show boto3-stubs documentation](./client.md#remove_notification_channel)
         """
 
@@ -254,7 +254,7 @@ class DevopsGuruClient:
         NextToken: str = None,
     ) -> SearchInsightsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.search_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.search_insights)
         [Show boto3-stubs documentation](./client.md#search_insights)
         """
 
@@ -264,7 +264,7 @@ class DevopsGuruClient:
         ClientToken: str = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.start_cost_estimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.start_cost_estimation)
         [Show boto3-stubs documentation](./client.md#start_cost_estimation)
         """
 
@@ -274,7 +274,7 @@ class DevopsGuruClient:
         ResourceCollection: UpdateResourceCollectionFilterTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.update_resource_collection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.update_resource_collection)
         [Show boto3-stubs documentation](./client.md#update_resource_collection)
         """
 
@@ -282,7 +282,7 @@ class DevopsGuruClient:
         self, ServiceIntegration: UpdateServiceIntegrationConfigTypeDef
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Client.update_service_integration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Client.update_service_integration)
         [Show boto3-stubs documentation](./client.md#update_service_integration)
         """
 
@@ -291,7 +291,7 @@ class DevopsGuruClient:
         self, operation_name: Literal["describe_resource_collection_health"]
     ) -> DescribeResourceCollectionHealthPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.DescribeResourceCollectionHealth)[Show boto3-stubs documentation](./paginators.md#describeresourcecollectionhealthpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)[Show boto3-stubs documentation](./paginators.md#describeresourcecollectionhealthpaginator)
         """
 
     @overload
@@ -299,7 +299,7 @@ class DevopsGuruClient:
         self, operation_name: Literal["get_cost_estimation"]
     ) -> GetCostEstimationPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.GetCostEstimation)[Show boto3-stubs documentation](./paginators.md#getcostestimationpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)[Show boto3-stubs documentation](./paginators.md#getcostestimationpaginator)
         """
 
     @overload
@@ -307,7 +307,7 @@ class DevopsGuruClient:
         self, operation_name: Literal["get_resource_collection"]
     ) -> GetResourceCollectionPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.GetResourceCollection)[Show boto3-stubs documentation](./paginators.md#getresourcecollectionpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)[Show boto3-stubs documentation](./paginators.md#getresourcecollectionpaginator)
         """
 
     @overload
@@ -315,19 +315,19 @@ class DevopsGuruClient:
         self, operation_name: Literal["list_anomalies_for_insight"]
     ) -> ListAnomaliesForInsightPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.ListAnomaliesForInsight)[Show boto3-stubs documentation](./paginators.md#listanomaliesforinsightpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)[Show boto3-stubs documentation](./paginators.md#listanomaliesforinsightpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_events"]) -> ListEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.ListEvents)[Show boto3-stubs documentation](./paginators.md#listeventspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)[Show boto3-stubs documentation](./paginators.md#listeventspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_insights"]) -> ListInsightsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.ListInsights)[Show boto3-stubs documentation](./paginators.md#listinsightspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)[Show boto3-stubs documentation](./paginators.md#listinsightspaginator)
         """
 
     @overload
@@ -335,7 +335,7 @@ class DevopsGuruClient:
         self, operation_name: Literal["list_notification_channels"]
     ) -> ListNotificationChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.ListNotificationChannels)[Show boto3-stubs documentation](./paginators.md#listnotificationchannelspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)[Show boto3-stubs documentation](./paginators.md#listnotificationchannelspaginator)
         """
 
     @overload
@@ -343,11 +343,11 @@ class DevopsGuruClient:
         self, operation_name: Literal["list_recommendations"]
     ) -> ListRecommendationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.ListRecommendations)[Show boto3-stubs documentation](./paginators.md#listrecommendationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)[Show boto3-stubs documentation](./paginators.md#listrecommendationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["search_insights"]) -> SearchInsightsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/devops-guru.html#DevopsGuru.Paginator.SearchInsights)[Show boto3-stubs documentation](./paginators.md#searchinsightspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)[Show boto3-stubs documentation](./paginators.md#searchinsightspaginator)
         """
